==> amazeui-vue-0.2.1.tgz: package/examples/public/app/8.app.js <==
webpackJsonp([8],{

/***/ 112:
/***/ function(module, exports, __webpack_require__) {

	module.exports = __webpack_require__(113)

	if (module.exports.__esModule) module.exports = module.exports.default
	;(typeof module.exports === "function" ? module.exports.options : module.exports).template = __webpack_require__(114)
	if (false) {
	(function () {
	var hotAPI = require("vue-hot-reload-api")
	hotAPI.install(require("vue"))
	if (!hotAPI.compatible) return
	var id = "-!babel-loader?presets[]=es2015&plugins[]=transform-runtime!./../../../node_modules/vue-loader/lib/selector.js?type=script&index=0!./breadcrumb.vue"
	hotAPI.createRecord(id, module.exports)
	module.hot.accept(["-!babel-loader?presets[]=es2015&plugins[]=transform-runtime!./../../../node_modules/vue-loader/lib/selector.js?type=script&index=0!./breadcrumb.vue","-!vue-html-loader!./../../../node_modules/vue-loader/lib/selector.js?type=template&index=0!./breadcrumb.vue"], function () {
	var newOptions = require("-!babel-loader?presets[]=es2015&plugins[]=transform-runtime!./../../../node_modules/vue-loader/lib/selector.js?type=script&index=0!./breadcrumb.vue")
	if (newOptions && newOptions.__esModule) newOptions = newOptions.default
	var newTemplate = require("-!vue-html-loader!./../../../node_modules/vue-loader/lib/selector.js?type=template&index=0!./breadcrumb.vue")
	hotAPI.update(id, newOptions, newTemplate)
	})
	})()
	}

/***/ },

/***/ 113:
/***/ function(module, exports) {

	"use strict";

	// <template>

	// <grid>

	//   <column :sm="12">

	//     <breadcrumb :menu="[{name:'Home',link:'/'},{name:'Components',link:'/'}]"></breadcrumb>

	//     <breadcrumb :menu="[{name:'首页',link:'/'},{name:'组件',link:'/'}]" slash></breadcrumb>

	//   </column>

	// </grid>

	// </template>

	// <script>

	module.exports = {};

	// </script>

/***/ },

/***/ 114:
/***/ function(module, exports) {

	module.exports = "<grid>\r\n  <column :sm=\"12\">\r\n    <breadcrumb :menu=\"[{name:'Home',link:'/'},{name:'Components',link:'/'}]\"></breadcrumb>\r\n    <breadcrumb :menu=\"[{name:'首页',link:'/'},{name:'组件',link:'/'}]\" slash></breadcrumb>\r\n  </column>\r\n</grid>";

/***/ }

});

==> amazeui-vue-0.2.4.tgz: package/examples/public/app/8.app.js <==
webpackJsonp([8],{

/***/ 112:
/***/ function(module, exports, __webpack_require__) {

	module.exports = __webpack_require__(113)

	if (module.exports.__esModule) module.exports = module.exports.default
	;(typeof module.exports === "function" ? module.exports.options : module.exports).template = __webpack_require__(114)
	if (false) {
	(function () {
	var hotAPI = require("vue-hot-reload-api")
	hotAPI.install(require("vue"))
	if (!hotAPI.compatible) return
	var id = "-!babel-loader?presets[]=es2015&plugins[]=transform-runtime!./../../../node_modules/vue-loader/lib/selector.js?type=script&index=0!./breadcrumb.vue"
	hotAPI.createRecord(id, module.exports)
	module.hot.accept(["-!babel-loader?presets[]=es2015&plugins[]=transform-runtime!./../../../node_modules/vue-loader/lib/selector.js?type=script&index=0!./breadcrumb.vue","-!vue-html-loader!./../../../node_modules/vue-loader/lib/selector.js?type=template&index=0!./breadcrumb.vue"], function () {
	var newOptions = require("-!babel-loader?presets[]=es2015&plugins[]=transform-runtime!./../../../node_modules/vue-loader/lib/selector.js?type=script&index=0!./breadcrumb.vue")
	if (newOptions && newOptions.__esModule) newOptions = newOptions.default
	var newTemplate = require("-!vue-html-loader!./../../../node_modules/vue-loader/lib/selector.js?type=template&index=0!./breadcrumb.vue")
	hotAPI.update(id, newOptions, newTemplate)
	})
	})()
	}

/***/ },

/***/ 113:
/***/ function(module, exports) {

	"use strict";

	// <template>

	// <grid>

	//   <column v-bind:sm="12">

	//     <breadcrumb v-bind:menu="[{name:'Home',link:'/'},{name:'Components',link:'/'}]"></breadcrumb>

	//     <breadcrumb v-bind:menu="[{name:'首页',link:'/'},{name:'组件',link:'/'}]" slash></breadcrumb>

	//   </column>

	// </grid>

	// </template>

	// <script>

	module.exports = {};

	// </script>

/***/ },

/***/ 114:
/***/ function(module, exports) {

	module.exports = "<grid>\r\n  <column v-bind:sm=\"12\">\r\n    <breadcrumb v-bind:menu=\"[{name:'Home',link:'/'},{name:'Components',link:'/'}]\"></breadcrumb>\r\n    <breadcrumb v-bind:menu=\"[{name:'首页',link:'/'},{name:'组件',link:'/'}]\" slash></breadcrumb>\r\n  </column>\r\n</grid>";

/***/ }

});
